#
# spec file for package perl-Scope-Upper
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Scope-Upper
Name:           perl-Scope-Upper
Version:        0.34
Release:        1.8
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Act on upper scopes
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/V/VP/VPIT/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
This module lets you defer actions _at run-time_ that will take place when
the control flow returns into an upper scope. Currently, you can:

  * hook an upper scope end with reap ;

  * localize variables, array/hash values or deletions of elements in higher
contexts with respectively localize, localize_elem and localize_delete ;

  * return values immediately to an upper level with unwind, yield and leave ;

  * gather information about an upper context with want_at and context_info ;

  * execute a subroutine in the setting of an upper subroutine stack frame with
uplevel ;

  * uniquely identify contexts with uid and validate_uid.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING README samples

%changelog
* Mon Mar 27 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.34
  see /usr/share/doc/packages/perl-Scope-Upper/Changes
  0.34    2023-03-26 16:00 UTC
    + Add : Contributing guidelines are now listed in the new
    CONTRIBUTING file.
    + Fix : [RT #146897] Scope::Upper does not know about RCPV
    cop_warnings, and does not know that given is deprecated.
    "given" related warnings were silenced, and the new RCPV
    interface is now used.
    Thanks Yves Orton for reporting and contributing a fix.
    + Fix : Assertion failures triggering on perl version 5.37.10 and
    higher with DEBUGGING enabled.
    + Fix : t/64-uplevel-caller.t has been taught about the new call frame
    numbering convention.
* Tue Dec 21 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.33
  see /usr/share/doc/packages/perl-Scope-Upper/Changes
  0.33    2021-12-20 20:30 UTC
    + Fix : [RT #114816] resources/remote/url points to web interface
    META files now follow version 2.0 of the CPAN META spec.
    Thanks Kent Fredric for reporting.
    + Fix : [RT #139823] : Perl 5 blead breads t/07-context_info.t
    t/07-context_info.t has been hardened against warning bits
    changes.
    Thanks Jim Keenan and Tony Cook for reporting and contributing
    a fix.
* Tue Jul 16 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.32
  see /usr/share/doc/packages/perl-Scope-Upper/Changes
  0.32    2019-07-08 12:50 UTC
    + Fix : [RT #129539] : fails with v5.27.3 and later with DEBUGGING
    The module has been amended to accomodate with a change of
    behaviour of a core macro.
    + Upd : Contact info.
* Mon Aug 27 2018 coolo@suse.com
- updated to 0.31
  see /usr/share/doc/packages/perl-Scope-Upper/Changes
  0.31    2018-08-26 19:50 UTC
    + Fix : [RT #125931] : localized SCALAR doesn't get imported
    localize '$Foo::x' => $var now properly imports $x into Foo.
    Thanks Vernon Lyon for reporting.
* Sun Nov  5 2017 coolo@suse.com
- updated to 0.30
  see /usr/share/doc/packages/perl-Scope-Upper/Changes
  0.30    2017-11-04 15:55 UTC
    + Fix : [RT #123481] : Compatibility with CV-in-stash optimisation
    Thanks Father Chrysostomos for reporting and contributing a
    patch.
* Sun Jun 12 2016 coolo@suse.com
- updated to 0.29
  see /usr/share/doc/packages/perl-Scope-Upper/Changes
  0.29    2016-06-06 12:00 UTC
    + Chg : A large chunk of boilerplate XS code, which is also used in
    other XS modules, has been factored out of the main .xs file
    to a collection of .h files in the xsh subdirectory.
    + Fix : [RT #112246] : Blead breaks Scope::Upper
    Dave Mitchell provided a new implementation of reap(),
    localize_*() and uplevel() to match the new context stack
    handling in perl 5.24. Many thanks to him.
* Sun Aug 23 2015 coolo@suse.com
- updated to 0.28
  see /usr/share/doc/packages/perl-Scope-Upper/Changes
  0.28    2015-08-18 15:00 UTC
    + Chg : SUB() and EVAL() will now warn if they cannot find an
    appropriate context in the current stack. They will still
    return undef in this case, which is interpreted as the current
    context when combined with other words.
    + Fix : [RT #104751] : Scope::Upper does not handle exotic stack types
    Trying to target a scope above the current perl scope will now
    result in a warning. In that case, the topmost context in the
    current stack will still be returned.
    Thanks Rafaël Garcia-Suarez for the report.
    + Fix : Test failures of threads tests on systems with harsh resource
    constraints causing the threads to exit() during run.
    + Opt : Some internal structures were shrunk, resulting in memory
    savings and small speedups.
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.27
  see /usr/share/doc/packages/perl-Scope-Upper/Changes
  0.27    2015-03-27 22:10 UTC
    + Chg : The new environment variable to enable thread tests on older
    perls is PERL_FORCE_TEST_THREADS. Note that this variable
    should only be turned on by authors.
    + Fix : Segfaults when the module is loaded by several threads (or
    Windows emulated processes) ran in parallel.
    + Fix : Memory leak with the uid() feature.
    + Fix : Update the Windows ActivePerl + gcc 3.4 workaround for
    ExtUtils::MakeMaker 7.04. Thanks Christian Walde for reporting
    and feedback on this issue.
    + Fix : reap(), localize(), localize_elem() and localize_delete()
    will again work correctly on perl 5.19.4+ when the debugger
    is enabled.
    + Fix : Silence some compiler warnings.
  0.26    2015-03-12 23:30 UTC
    + Fix : [RT #100264] : Don't use CvPADLIST on XSUBs
    Thanks Father Chrysostomos for reporting and contributing a
    patch.
    + Fix : Be really compatible with the optional OP_PARENT feature.
  0.25    2014-09-21 17:10 UTC
    + Add : Support for the PERL_OP_PARENT optional feature introduced in
    perl 5.21.2.
    + Fix : Work around an assertion failure in perl 5.21.4.
* Fri Oct  4 2013 coolo@suse.com
- updated to 0.24
    + Fix : Lexicals returned with unwind(), yield() and leave() will no
    longer be lost on perl 5.19.4 and above.
    This is a maintenance release. The code contains no functional change.
    Satisfied users of version 0.22 can skip this update.
    + Fix : [RT #87178] : typo fixes.
    Thanks dsteinbrunner@pobox.com for the patch.
    + Fix : [RT #88177] : 5.19.3 block hint test breakage
    t/07-context_info.t has been taught about perl 5.19.3.
    Thanks Andrew Main for the patch.
    + Tst : Author tests are no longer bundled with this distribution.
    They are only made available to authors in the git repository.
    + Tst : "given is experimental" warnings when running tests on perl
    5.18 and above have been silenced.
* Tue Jun  4 2013 coolo@suse.com
- updated to 0.22
    + Chg : perl 5.6.1 is required.
    + Fix : context_info() now ignores %%warnings::Bits for perl 5.8.6 and
    below, just like caller().
    + Fix : [RT #82220] : Scope-Upper-0.21 test stuck on Windows perl 5.12.3
    t/93-pod-spelling.t will not crash anymore on perl 5.12 and
    below.
    Thanks Gabor Szabo for reporting and Slaven Rezic for debugging
    this issue.
    + Tst : Rare test failures of t/07-context_info.t on perl 5.6,
    t/55-yield-target.t on perl 5.[68], and t/63-uplevel-ctl.t on
    perl 5.8.[345] have been addressed.
    + Fix : context_info() has been taught about perl 5.17.4.
    + Fix : t/07-context_info.t will no longer fail with perls that have
    sitecustomize enabled (like many perl builds for Windows).
    Thanks Steve Hay and Nicholas Clark for debugging help.
    + Fix : Broken linkage on Windows with gcc 3.4, which appears in
    particular when using ActivePerl's default compiler suite.
    For those setups, the Scope::Upper shared library will now be
    linked against the perl dll directly (instead of the import
    library).
    + Add : The new yield(@values, $context) function can be used to return
    values to any upper scope, including do or map blocks.
    The new leave(@values) function is an alias for
    yield(@values, HERE).
    + Add : The new context_info($context) function return information
    about context $context, similarly to what caller() provides
    but for any upper scope.
    + Chg : Contexts are now normalized. In previous versions, it was
    possible for different contexts to refer to the same scope :
    for example, "for (my $i = 0; $i < 10; ++$i) { ... }" was
    reachable through two contexts, while "for (@array) { ... }"
    only by one. Starting from this version, contexts are
    normalized so that they always represent an actual scope.
    + Doc : C++ compilers are officially NOT supported.
    + Fix : Building with a more recent version of perl 5.17.4.
    + Fix : Debugger compatibility with perl 5.17.1 and above.
    + Doc : POD headings have been made linkable.
    + Fix : Building with perl 5.17.4.
    + Fix : BUILD_PREREQS are now set for ExtUtils::MakeMaker.
    + Opt : uplevel() private data structure is 7%% smaller on 64 bits
    architectures.
    + Tst : Author tests overhaul.
* Wed Dec 28 2011 coolo@suse.com
- update to 0.18
    + Add : The uid() function returns an unique identifier for each dynamic
    scope. The validate_uid() function can be used to check whether
    one such identifier is valid (i.e. that the scope it refers to
    is still alive).
    + Chg : It is no longer possible on perl 5.6 to call goto() in an
    uplevel callback to replace the uplevel call. This change was
    needed in order to ensure consistency between platforms
    regarding to the following fix just below.
    + Fix : The uplevel() tests now pass on Windows.
    Thanks C.H. Kang for bringing this to my attention.
* Fri Apr 29 2011 coolo@opensuse.org
- updated to 0.14
    + Fix : [RT #64997] : Compatibility with perl 5.13.10.
    Thanks Dave Mitchell for the notice.
    + Tst : Lengthy tests have been ported to Test::Leaner, making the
    whole test suite about 50%% faster.
    + Fix : [RT #61904] : Stack corruption when using unwind() under
    Devel::NYTProf.
    Thanks Sergey Aleynikov for contributing a fix.
    + Fix : [RT #63378] : Compatibility with perl 5.13.8.
    Thanks Andreas J. König for bisecting the issue.
    + Tst : Threads tests are now only run on perl 5.13.4 and higher.
    They could segfault randomly because of what seems to be an
    internal bug of Perl, which has been addressed in 5.13.4.
    There is also an environment variable that allows you to
    forcefully run those tests, but it should be set only for
    author testing and not for end users.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Thu Nov  4 2010 pascal.bleser@opensuse.org
- initial version (0.12)
